==> zio-aws-sagemaker_2.12-6.20.103.1-sources.jar: zio/aws/sagemaker/model/AutoMLMetricExtendedEnum.scala <==
package zio.aws.sagemaker.model
import scala.jdk.CollectionConverters._
sealed trait AutoMLMetricExtendedEnum {
  def unwrap
      : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum
}
object AutoMLMetricExtendedEnum {
  def wrap(
      value: software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum
  ): zio.aws.sagemaker.model.AutoMLMetricExtendedEnum = value match {
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ACCURACY =>
      val r = Accuracy
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MSE =>
      val r = MSE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1 =>
      val r = F1
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1_MACRO =>
      val r = F1macro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AUC =>
      val r = AUC
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RMSE =>
      val r = RMSE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAE =>
      val r = MAE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.R2 =>
      val r = R2
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.BALANCED_ACCURACY =>
      val r = BalancedAccuracy
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION =>
      val r = Precision
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION_MACRO =>
      val r = PrecisionMacro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL =>
      val r = Recall
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL_MACRO =>
      val r = RecallMacro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.LOG_LOSS =>
      val r = LogLoss
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.INFERENCE_LATENCY =>
      val r = InferenceLatency
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAPE =>
      val r = MAPE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MASE =>
      val r = MASE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.WAPE =>
      val r = WAPE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AVERAGE_WEIGHTED_QUANTILE_LOSS =>
      val r = AverageWeightedQuantileLoss
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.UNKNOWN_TO_SDK_VERSION
  }
  case object Accuracy
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ACCURACY
  }
  case object MSE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MSE
  }
  case object F1 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1
  }
  case object F1macro extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1_MACRO
  }
  case object AUC extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AUC
  }
  case object RMSE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RMSE
  }
  case object MAE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAE
  }
  case object R2 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.R2
  }
  case object BalancedAccuracy
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.BALANCED_ACCURACY
  }
  case object Precision
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION
  }
  case object PrecisionMacro
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION_MACRO
  }
  case object Recall extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL
  }
  case object RecallMacro
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL_MACRO
  }
  case object LogLoss extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.LOG_LOSS
  }
  case object InferenceLatency
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.INFERENCE_LATENCY
  }
  case object MAPE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAPE
  }
  case object MASE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MASE
  }
  case object WAPE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.WAPE
  }
  case object AverageWeightedQuantileLoss
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AVERAGE_WEIGHTED_QUANTILE_LOSS
  }
}

==> zio-aws-sagemaker_2.12-7.21.15.3-sources.jar: zio/aws/sagemaker/model/AutoMLMetricExtendedEnum.scala <==
package zio.aws.sagemaker.model
import scala.jdk.CollectionConverters._
sealed trait AutoMLMetricExtendedEnum {
  def unwrap
      : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum
}
object AutoMLMetricExtendedEnum {
  def wrap(
      value: software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum
  ): zio.aws.sagemaker.model.AutoMLMetricExtendedEnum = value match {
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ACCURACY =>
      val r = Accuracy
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MSE =>
      val r = MSE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1 =>
      val r = F1
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1_MACRO =>
      val r = F1macro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AUC =>
      val r = AUC
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RMSE =>
      val r = RMSE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAE =>
      val r = MAE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.R2 =>
      val r = R2
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.BALANCED_ACCURACY =>
      val r = BalancedAccuracy
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION =>
      val r = Precision
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION_MACRO =>
      val r = PrecisionMacro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL =>
      val r = Recall
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL_MACRO =>
      val r = RecallMacro
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.LOG_LOSS =>
      val r = LogLoss
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.INFERENCE_LATENCY =>
      val r = InferenceLatency
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAPE =>
      val r = MAPE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MASE =>
      val r = MASE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.WAPE =>
      val r = WAPE
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AVERAGE_WEIGHTED_QUANTILE_LOSS =>
      val r = AverageWeightedQuantileLoss
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE1 =>
      val r = Rouge1
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE2 =>
      val r = Rouge2
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGEL =>
      val r = RougeL
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE_L_SUM =>
      val r = RougeLSum
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PERPLEXITY =>
      val r = Perplexity
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.VALIDATION_LOSS =>
      val r = ValidationLoss
      r
    case software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.TRAINING_LOSS =>
      val r = TrainingLoss
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.UNKNOWN_TO_SDK_VERSION
  }
  case object Accuracy
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ACCURACY
  }
  case object MSE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MSE
  }
  case object F1 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1
  }
  case object F1macro extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.F1_MACRO
  }
  case object AUC extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AUC
  }
  case object RMSE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RMSE
  }
  case object MAE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAE
  }
  case object R2 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.R2
  }
  case object BalancedAccuracy
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.BALANCED_ACCURACY
  }
  case object Precision
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION
  }
  case object PrecisionMacro
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PRECISION_MACRO
  }
  case object Recall extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL
  }
  case object RecallMacro
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.RECALL_MACRO
  }
  case object LogLoss extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.LOG_LOSS
  }
  case object InferenceLatency
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.INFERENCE_LATENCY
  }
  case object MAPE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MAPE
  }
  case object MASE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.MASE
  }
  case object WAPE extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.WAPE
  }
  case object AverageWeightedQuantileLoss
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.AVERAGE_WEIGHTED_QUANTILE_LOSS
  }
  case object Rouge1 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE1
  }
  case object Rouge2 extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE2
  }
  case object RougeL extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGEL
  }
  case object RougeLSum
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.ROUGE_L_SUM
  }
  case object Perplexity
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.PERPLEXITY
  }
  case object ValidationLoss
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.VALIDATION_LOSS
  }
  case object TrainingLoss
      extends zio.aws.sagemaker.model.AutoMLMetricExtendedEnum {
    override def unwrap
        : software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum =
      software.amazon.awssdk.services.sagemaker.model.AutoMLMetricExtendedEnum.TRAINING_LOSS
  }
}
